=======
Authors
=======

.. List format (alphabetical order):  Surname, Name. Employer/Affiliation

* Benedicic, Lucas. ETH Zurich - CSCS
* Cruz, Felipe. ETH Zurich - CSCS
* Dahm, Johann. Allen Institute for AI
* Davis, Eddie. Allen Institute for AI
* Ehrengruber, Till. ETH Zurich - CSCS
* George, Rhea. Allen Institute for AI
* González Paredes, Enrique. ETH Zurich - CSCS
* Groner, Linus. ETH Zurich - CSCS
* Häuselmann, Rico. ETH Zurich - CSCS
* Madonna, Alberto. ETH Zurich - CSCS
* Mariotti, Kean. ETH Zurich - CSCS
* Müller, Christoph. MeteoSwiss
* Osuna, Carlos. MeteoSwiss
* Röthlin, Matthias. MeteoSwiss
* Serafini, Giacomo. MeteoSwiss
* Szenes, Kalman. ETH Zurich - CSCS
* Thaler, Felix. ETH Zurich - CSCS
* Ubbiali, Stefano. ETH Zurich
* Vogt, Hannes. ETH Zurich - CSCS
* Weber, Benjamin. MeteoSwiss
* Wicky, Tobias. Allen Institute for AI
